==> monocdk-1.72.0.tar.gz: package/lib/aws-docdb/lib/endpoint.d.ts <==
/**
 * (experimental) Connection endpoint of a database cluster or instance.
 *
 * Consists of a combination of hostname and port.
 *
 * @experimental
 */
export declare class Endpoint {
    /**
     * The minimum port value
     */
    private static readonly MIN_PORT;
    /**
     * The maximum port value
     */
    private static readonly MAX_PORT;
    /**
     * Determines if a port is valid
     *
     * @param port: The port number
     * @returns boolean whether the port is valid
     */
    private static isValidPort;
    /**
     * (experimental) The hostname of the endpoint.
     *
     * @experimental
     */
    readonly hostname: string;
    /**
     * (experimental) The port number of the endpoint.
     *
     * This can potentially be a CDK token. If you need to embed the port in a string (e.g. instance user data script),
     * use {@link Endpoint.portAsString}.
     *
     * @experimental
     */
    readonly port: number;
    /**
     * (experimental) The combination of "HOSTNAME:PORT" for this endpoint.
     *
     * @experimental
     */
    readonly socketAddress: string;
    /**
     * (experimental) Constructs an Endpoint instance.
     *
     * @param address - The hostname or address of the endpoint.
     * @param port - The port number of the endpoint.
     * @experimental
     */
    constructor(address: string, port: number);
    /**
     * (experimental) Returns the port number as a string representation that can be used for embedding within other strings.
     *
     * This is intended to deal with CDK's token system. Numeric CDK tokens are not expanded when their string
     * representation is embedded in a string. This function returns the port either as an unresolved string token or
     * as a resolved string representation of the port value.
     *
     * @returns An (un)resolved string representation of the endpoint's port number
     * @experimental
     */
    portAsString(): string;
}

==> monocdk-1.106.1.tar.gz: package/lib/aws-docdb/lib/endpoint.d.ts <==
/**
 * (experimental) Connection endpoint of a database cluster or instance.
 *
 * Consists of a combination of hostname and port.
 *
 * @experimental
 */
export declare class Endpoint {
    /**
     * The minimum port value
     */
    private static readonly MIN_PORT;
    /**
     * The maximum port value
     */
    private static readonly MAX_PORT;
    /**
     * Determines if a port is valid
     *
     * @param port: The port number
     * @returns boolean whether the port is valid
     */
    private static isValidPort;
    /**
     * (experimental) The hostname of the endpoint.
     *
     * @experimental
     */
    readonly hostname: string;
    /**
     * (experimental) The port number of the endpoint.
     *
     * This can potentially be a CDK token. If you need to embed the port in a string (e.g. instance user data script),
     * use {@link Endpoint.portAsString}.
     *
     * @experimental
     */
    readonly port: number;
    /**
     * (experimental) The combination of ``HOSTNAME:PORT`` for this endpoint.
     *
     * @experimental
     */
    readonly socketAddress: string;
    /**
     * (experimental) Constructs an Endpoint instance.
     *
     * @param address - The hostname or address of the endpoint.
     * @param port - The port number of the endpoint.
     * @experimental
     */
    constructor(address: string, port: number);
    /**
     * (experimental) Returns the port number as a string representation that can be used for embedding within other strings.
     *
     * This is intended to deal with CDK's token system. Numeric CDK tokens are not expanded when their string
     * representation is embedded in a string. This function returns the port either as an unresolved string token or
     * as a resolved string representation of the port value.
     *
     * @returns An (un)resolved string representation of the endpoint's port number
     * @experimental
     */
    portAsString(): string;
}
